arm_body_is_statement

Function arm_body_is_statement 

pub fn arm_body_is_statement(body: &AIRNode) -> bool
Returns true if a match-arm body is a statement body — either the body is itself a statement node, or it is a { ... } block whose tail is a statement node (or which has no tail at all, e.g. a block ending in a statement with no value).