pub fn is_target_keyword(name: &str, target: KeywordTarget) -> boolExpand description
True when name is a reserved word in the given target’s keyword set.
pub fn is_target_keyword(name: &str, target: KeywordTarget) -> boolTrue when name is a reserved word in the given target’s keyword set.