pub struct SourceMapping {
pub gen_line: u32,
pub gen_col: u32,
pub src_line: u32,
pub src_col: u32,
pub src_offset: u32,
pub src_file_id: u32,
}Expand description
A single pointwise mapping from a position in generated code to a position in the originating Bock source.
Fields
gen_line: u321-indexed line in the generated file.
gen_col: u321-indexed column (character count) in the generated file.
src_line: u321-indexed source line. 0 means unresolved — call
SourceMap::resolve_positions with source content to fill this in.
src_col: u321-indexed source column. 0 when unresolved.
src_offset: u32Byte offset into the source file; used to (re)compute line/col.
src_file_id: u32File-registry id of the source file (index into SourceMap::sources).